%% Demo 1 - Synthetic data (Ring)
%

% The black ring exhibits two different kind of intensity borders. The
% inner border represents a bright-to-dark intensity transition, while the
% outer border represents a dark-to-bright intensity transition in outwards
% direction of the white circle.
im = im2double(imread('demo/ring.tif'));
figure; imshow(im);

%
% Run graph cut segmentation with different types of boundary costs
%
params = struct('debugMode', 1);

% symmetric boundary costs         
params.lambda = 1;
params.binaryTermType = 'symmetric';
params.sigma = 0.5;
predLabels_symm = runTracking('demo/ring.tif','demo/model_ring.mat', params);

% asymmetric boundary costs (dark-to-bright preference)     
params.lambda = 1;
params.binaryTermType = 'asymmetric-darkToBright';
params.sigma = 0.5;
predLabels_asymm_db = runTracking('demo/ring.tif','demo/model_ring.mat', params);

% asymmetric boundary costs (bright-to-dark preference)       
params.lambda = 1;
params.binaryTermType = 'asymmetric-brightToDark';
params.sigma = 0.5;
predLabels_asymm_bd = runTracking('demo/ring.tif','demo/model_ring.mat', params);

%
% Comparison
%
im = im2double(imread('demo/ring.tif'));
nPixel = numel(im);
contour_symm = edge(double(predLabels_symm(:,:,1)'));
contour_asymm_db = edge(double(predLabels_asymm_db(:,:,1)'));
contour_asymm_bd = edge(double(predLabels_asymm_bd(:,:,1)'));
idx=find(contour_symm);
overlay_symm = cat(3, im, im+0.5*double(predLabels_symm(:,:,1)'), im+0.5*double(predLabels_symm(:,:,1)'));
overlay_symm(idx) = 0; overlay_symm(nPixel+idx) = 2; overlay_symm(2*nPixel+idx) = 2;
overlay_symm = overlay_symm / max(overlay_symm(:));
idx=find(contour_asymm_db);
overlay_asymm_db = cat(3, im+0.5*double(predLabels_asymm_db(:,:,1)'), im, im);
overlay_asymm_db(idx) = 2; overlay_asymm_db(nPixel+idx) = 0; overlay_asymm_db(2*nPixel+idx) = 0;
overlay_asymm_db = overlay_asymm_db / max(overlay_asymm_db(:));
idx=find(contour_asymm_bd);
overlay_asymm_bd = cat(3, im+0.5*double(predLabels_asymm_bd(:,:,1)'), im, im);
overlay_asymm_bd(idx) = 2; overlay_asymm_bd(nPixel+idx) = 0; overlay_asymm_bd(2*nPixel+idx) = 0;
overlay_asymm_bd = overlay_asymm_bd / max(overlay_asymm_bd(:));

figure('units','normalized','outerposition',[0 0 1 1]);
subplot(2,2,1); imshow(im,[]); title('Raw image','FontSize',10);
subplot(2,2,2); imshow(overlay_symm); 
title('Graph cut segmentation', 'FontSize',10); xlabel('Symmetric boundary costs (mask and contour in cyan)');
subplot(2,2,3); imshow(overlay_asymm_db); 
title('Graph cut segmentation', 'FontSize',10); xlabel('Asymmetric boundary costs / dark-to-bright preference (mask and contour in red)');
subplot(2,2,4); imshow(overlay_asymm_bd); 
title('Graph cut segmentation', 'FontSize',10); xlabel('Asymmetric boundary costs / bright-to-dark preference (mask and contour in red)');
