%% Demos
%   Several demos demonstrate the method on synthetic data, on phase
%   contrast microscopy images and show how to apply the code on your own
%   data.
%
%   Corresponding publication:
%   Robert Bensch and Olaf Ronneberger. Cell segmentation and tracking in
%   phase contrast images using graph cut with asymmetric boundary costs. 
%   In IEEE International Symposium on Biomedical Imaging (ISBI), 2015.
%
%   (c) 2015 Robert Bensch, Computer Science Department, University of Freiburg, Germany
%

close all;
clear;

% Enter the path to the matlab code directory here:
path = '';

addpath(genpath(path));
cd(path)

%% Demo 1 - Synthetic data (Ring)
%   comparion between symmetric and asymmetric boundary costs
demo1

%% Demo 2 - Phase contrast microscopy images
%

% Single cell segmentation
%   and comparsion between symmetric and asymmetric boundary costs
demo2a

% Full view segmentation
%   and comparsion between symmetric and asymmetric boundary costs
demo2b

% Sequence segmentation and tracking
%   using graph cut with asymmetric boundary costs
demo2c

%% Demo 3 - How to apply the code to your own data
%

%
% 1) Train a region model
%     extracts foreground and background intensity histograms from manual
%     labels
params = struct;
params.doPreSmoothing = 0;
params.preSmoothSigma = 0.5;
params.doBackgroundSubstr = 1;
params.bgrSubstrSigma = 20.0;
params.nBins = 120;

fileStr = 'demo/cell.tif';
model = trainModel( fileStr, params);

save('demo/model.mat', 'model');

%
% 2) Set the desired parameters
%     and run cell segmentation and tracking
%
% Hints:
% - All parameters available are contained in runTracking.m
% - The graph cut parameters lambda and sigma can be estimated on training
%   data including ground truth segmentation masks using grid-search, for
%   example.
%
params = struct('debugMode', 1);
params.lambda = 0.2;
params.binaryTermType = 'asymmetric-darkToBright';
params.sigma = 0.006;
[predLabels, fileLst] = runTracking('demo/cell.tif','demo/model.mat', params);

%
% 3) Visualize the results
%
im = im2double(imread(['demo/' fileLst{1}]));
labels = double(predLabels(:,:,1)');
figure;
subplot(1,3,1); imshow(im); title('Raw image');
subplot(1,3,2); imshow(labels); title('Segmentation mask');
subplot(1,3,3); imshow(cat(3, im+0.5*labels, im, im),[]); title('Overlay');
