function [predLabels, varargout] = runTracking( inFiles, modelFile, params_user )
% Runs cell tracking method
%   inFiles:      input files string (e.g. 'test/t*.tif')
%   modelFile:    foreground/background model file (*.mat filename)
%   params_user:  user specified parameters (struct that updates the standard parameters below)
%
%   (c) 2015 Robert Bensch, Computer Science Department, University of Freiburg, Germany
%

%
% Load foreground/background model
%
disp(['load model file: ' modelFile]);
ld = load(modelFile, 'model');     

%
% Standard parameters
%
params = struct;
params.model = ld.model;
% Preprocessing
params.doPreSmoothing = 0;
params.preSmoothSigma = 0.5;
% Binary term
params.nNeigh = 8;
% binaryTermType: 
%   {'symmetric', 'asymmetric-darkToBright', 'asymmetric-brightToDark'}
params.binaryTermType = 'asymmetric-darkToBright';
params.sigma = 0.006;
% Lambda
params.lambda =  0.2;
% Postprocessing
params.useFillHoles = 0;
params.minSegmAreaPx = 0;
% Segmentation propagation / Tracking
params.useFgrPropagation = 0;
params.erosion_size = 15;
params.useNonMergingConstr = 0;
params.tracking_useFillHoles = 0;
params.tracking_minSegmAreaPx = 0;
params.FOI_E = 0;

params.writeFiles = false;
params.outDir = '';
params.debugMode = 0;

%
% Update parameters with user specified parameters
%
params = update_struct(params, params_user);

%
% Cell segmentation
%
fprintf('\nrun cell segmentation\n');
[predLabels, fileLst] = segmentCells( inFiles, params);

%
% Cell tracking
%
params.fileLst = fileLst;
fprintf('\nrun cell tracking\n');
predLabels = trackCells(predLabels, params);

varargout{1} = fileLst;

end

